@@ -28,6 +28,7 @@
 #include <unistd.h>
 
 #include "sysprof-platform.h"
+#include "sysprof-capture-util-private.h"
 
 static void
 copy_into (GHashTable *src,
@@ -54,7 +55,7 @@ test_reader_basic (void)
 
   writer = sysprof_capture_writer_new ("capture-file", 0);
   g_assert (writer != NULL);
-  g_assert_cmpint (sysprof_capture_writer_get_buffer_size (writer), ==, 4096*64);
+  g_assert_cmpint (sysprof_capture_writer_get_buffer_size (writer), ==, _sysprof_getpagesize()*64);
 
   sysprof_capture_writer_flush (writer);
 
